from django.forms import Textarea
from django.template import Context
from django.template.loader import get_template
# from django.utils.safestring import mark_safe


class MarkdownInput(Textarea):
    def __init__(self, attrs=None, image_control=True):
        self.image_control = image_control

        default_attrs = {
            'class': 'form-control',
        }
        if attrs:
            default_attrs.update(attrs)

        super(Textarea, self).__init__(default_attrs)

    def render(self, name, value, attrs=None):
        textarea = Textarea.render(self, name, value)

        t = get_template('django_bootstrap_markdown/widget.html')
        c = Context({
            'show_image_button': self.image_control,
            'textarea': textarea,
        })

        return t.render(c)

    class Media:
        js = (
            '//cdnjs.cloudflare.com/ajax/libs/marked/0.2.9/marked.min.js',
            '//cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/3.0.3a/ekko-lightbox.min.js',
            'js/jquery.textarea.min.js',
            'js/django_bootstrap_markdown.js',
        )
        css = {
            'all': (
                '//cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/3.0.3a/ekko-lightbox.min.css',
                'css/django_bootstrap_markdown.css',
            )
        }



from django.conf.urls import patterns, include, url

urlpatterns = patterns('django_bootstrap_markdown.views',
    url(r'^image/$', 'markdown_image'),
    url(r'^image/library/$', 'markdown_library'),
)



from django.shortcuts import render
from django.contrib.auth.decorators import login_required
from django_bootstrap_markdown.models import Image
from django_bootstrap_markdown.forms import ImageForm, LibraryForm


@login_required
def markdown_image(request):
    if request.method == 'POST':
        form = ImageForm(request.POST, request.FILES)
        if form.is_valid():
            image = Image()
            image.original = form.cleaned_data['image']
            image.description = form.cleaned_data['description']
            image.save()

            if form.cleaned_data['size'] == 'Small':
                thumbnail = image.small
            elif form.cleaned_data['size'] == 'Medium':
                thumbnail = image.medium
            elif form.cleaned_data['size'] == 'Large':
                thumbnail = image.large
            elif form.cleaned_data['size'] == 'Original':
                thumbnail = image.original
            else:
                thumbnail = image.billboard

            return render(
                request,
                'django_bootstrap_markdown/markdown_image.html', {
                    'form': form,
                    'image': image,
                    'thumbnail': thumbnail,
                }
            )
    else:
        form = ImageForm()

    return render(request, 'django_bootstrap_markdown/markdown_image.html', {
        'form': form,
    })


@login_required
def markdown_library(request):
    if request.method == 'POST':
        form = LibraryForm(request.POST)
        if form.is_valid():
            image = form.cleaned_data['image']

            if form.cleaned_data['size'] == 'Small':
                thumbnail = image.small
            elif form.cleaned_data['size'] == 'Medium':
                thumbnail = image.medium
            elif form.cleaned_data['size'] == 'Large':
                thumbnail = image.large
            elif form.cleaned_data['size'] == 'Original':
                thumbnail = image.original
            else:
                thumbnail = image.billboard

            return render(
                request,
                'django_bootstrap_markdown/markdown_library.html', {
                    'form': form,
                    'image': image,
                    'thumbnail': thumbnail,
                }
            )
    else:
        form = LibraryForm()

    return render(request, 'django_bootstrap_markdown/markdown_library.html', {
        'images': Image.objects.all(),
        'form': form,
    })
